@@ -3,9 +3,9 @@
 
 __author__ = "Robin 'r0w' Weiland"
 __date__ = "2020-06-05"
-__version__ = "0.0.4"
+__version__ = "0.0.7"
 
-__all__ = ('API',)
+__all__ = ('API', 'Filter', 'Method', 'Container',)
 
 from api_bridge.api import API
 from api_bridge.filter import Filter
