@@ -3,7 +3,7 @@
 
 __author__ = "Robin 'r0w' Weiland"
 __date__ = "2020-08-15"
-__version__ = "0.0.4"
+__version__ = "0.0.7"
 
 __all__ = ('Method',)
 
@@ -11,8 +11,8 @@ from enum import Enum, auto
 
 
 class AutoName(Enum):
-    def _generate_next_value_(name, start, count, last_values):
-        return name
+    def _generate_next_value_(self, start, count, last_values):
+        return self
 
 
 class Method(AutoName):
